from . import sim_pb2_grpc as importStub

class SimService(object):

    def __init__(self, router):
        self.connector = router.get_connection(SimService, importStub.SimStub)

    def removeRule(self, request, timeout=None):
        return self.connector.create_request('removeRule', request, timeout)

    def getRulesInfo(self, request, timeout=None):
        return self.connector.create_request('getRulesInfo', request, timeout)

    def getRelatedRules(self, request, timeout=None):
        return self.connector.create_request('getRelatedRules', request, timeout)

    def touchRule(self, request, timeout=None):
        return self.connector.create_request('touchRule', request, timeout)


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from th2_grpc_sim import sim_pb2 as th2__grpc__sim_dot_sim__pb2


class SimStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.removeRule = channel.unary_unary(
                '/Sim/removeRule',
                request_serializer=th2__grpc__sim_dot_sim__pb2.RuleID.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.getRulesInfo = channel.unary_unary(
                '/Sim/getRulesInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=th2__grpc__sim_dot_sim__pb2.RulesInfo.FromString,
                )
        self.getRelatedRules = channel.unary_unary(
                '/Sim/getRelatedRules',
                request_serializer=th2__grpc__sim_dot_sim__pb2.RuleRelation.SerializeToString,
                response_deserializer=th2__grpc__sim_dot_sim__pb2.RulesInfo.FromString,
                )
        self.touchRule = channel.unary_unary(
                '/Sim/touchRule',
                request_serializer=th2__grpc__sim_dot_sim__pb2.TouchRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class SimServicer(object):
    """Missing associated documentation comment in .proto file."""

    def removeRule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getRulesInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getRelatedRules(self, request, context):
        """
        getRelatedRules method will return all rules configured with the given relation attribute
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def touchRule(self, request, context):
        """
        Calling 'touch' method on a rule that can send messages.
        You can set your own arguments for this request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SimServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'removeRule': grpc.unary_unary_rpc_method_handler(
                    servicer.removeRule,
                    request_deserializer=th2__grpc__sim_dot_sim__pb2.RuleID.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'getRulesInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getRulesInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=th2__grpc__sim_dot_sim__pb2.RulesInfo.SerializeToString,
            ),
            'getRelatedRules': grpc.unary_unary_rpc_method_handler(
                    servicer.getRelatedRules,
                    request_deserializer=th2__grpc__sim_dot_sim__pb2.RuleRelation.FromString,
                    response_serializer=th2__grpc__sim_dot_sim__pb2.RulesInfo.SerializeToString,
            ),
            'touchRule': grpc.unary_unary_rpc_method_handler(
                    servicer.touchRule,
                    request_deserializer=th2__grpc__sim_dot_sim__pb2.TouchRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Sim', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Sim(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def removeRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Sim/removeRule',
            th2__grpc__sim_dot_sim__pb2.RuleID.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getRulesInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Sim/getRulesInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            th2__grpc__sim_dot_sim__pb2.RulesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getRelatedRules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Sim/getRelatedRules',
            th2__grpc__sim_dot_sim__pb2.RuleRelation.SerializeToString,
            th2__grpc__sim_dot_sim__pb2.RulesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def touchRule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Sim/touchRule',
            th2__grpc__sim_dot_sim__pb2.TouchRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_sim/sim.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_sim/sim.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\031com.exactpro.th2.sim.grpcP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16th2_grpc_sim/sim.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cth2_grpc_common/common.proto\"\x14\n\x06RuleID\x12\n\n\x02id\x18\x01 \x01(\x05\" \n\x0cRuleRelation\x12\x10\n\x08relation\x18\x01 \x01(\t\"c\n\x08RuleInfo\x12\x13\n\x02id\x18\x01 \x01(\x0b\x32\x07.RuleID\x12\x12\n\nclass_name\x18\x02 \x01(\t\x12\r\n\x05\x61lias\x18\x03 \x01(\t\x12\x1f\n\x08relation\x18\x04 \x01(\x0b\x32\r.RuleRelation\"$\n\tRulesInfo\x12\x17\n\x04info\x18\x01 \x03(\x0b\x32\t.RuleInfo\"w\n\x0cTouchRequest\x12\x13\n\x02id\x18\x01 \x01(\x0b\x32\x07.RuleID\x12%\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x17.TouchRequest.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xd2\x01\n\x03Sim\x12/\n\nremoveRule\x12\x07.RuleID\x1a\x16.google.protobuf.Empty\"\x00\x12\x34\n\x0cgetRulesInfo\x12\x16.google.protobuf.Empty\x1a\n.RulesInfo\"\x00\x12.\n\x0fgetRelatedRules\x12\r.RuleRelation\x1a\n.RulesInfo\"\x00\x12\x34\n\ttouchRule\x12\r.TouchRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x1d\n\x19\x63om.exactpro.th2.sim.grpcP\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,th2__grpc__common_dot_common__pb2.DESCRIPTOR,])




_RULEID = _descriptor.Descriptor(
  name='RuleID',
  full_name='RuleID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='RuleID.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=105,
)


_RULERELATION = _descriptor.Descriptor(
  name='RuleRelation',
  full_name='RuleRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='relation', full_name='RuleRelation.relation', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=139,
)


_RULEINFO = _descriptor.Descriptor(
  name='RuleInfo',
  full_name='RuleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='RuleInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='RuleInfo.class_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='RuleInfo.alias', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relation', full_name='RuleInfo.relation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=240,
)


_RULESINFO = _descriptor.Descriptor(
  name='RulesInfo',
  full_name='RulesInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='RulesInfo.info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=278,
)


_TOUCHREQUEST_ARGSENTRY = _descriptor.Descriptor(
  name='ArgsEntry',
  full_name='TouchRequest.ArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='TouchRequest.ArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='TouchRequest.ArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=399,
)

_TOUCHREQUEST = _descriptor.Descriptor(
  name='TouchRequest',
  full_name='TouchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='TouchRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='TouchRequest.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TOUCHREQUEST_ARGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=399,
)

_RULEINFO.fields_by_name['id'].message_type = _RULEID
_RULEINFO.fields_by_name['relation'].message_type = _RULERELATION
_RULESINFO.fields_by_name['info'].message_type = _RULEINFO
_TOUCHREQUEST_ARGSENTRY.containing_type = _TOUCHREQUEST
_TOUCHREQUEST.fields_by_name['id'].message_type = _RULEID
_TOUCHREQUEST.fields_by_name['args'].message_type = _TOUCHREQUEST_ARGSENTRY
DESCRIPTOR.message_types_by_name['RuleID'] = _RULEID
DESCRIPTOR.message_types_by_name['RuleRelation'] = _RULERELATION
DESCRIPTOR.message_types_by_name['RuleInfo'] = _RULEINFO
DESCRIPTOR.message_types_by_name['RulesInfo'] = _RULESINFO
DESCRIPTOR.message_types_by_name['TouchRequest'] = _TOUCHREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RuleID = _reflection.GeneratedProtocolMessageType('RuleID', (_message.Message,), {
  'DESCRIPTOR' : _RULEID,
  '__module__' : 'th2_grpc_sim.sim_pb2'
  # @@protoc_insertion_point(class_scope:RuleID)
  })
_sym_db.RegisterMessage(RuleID)

RuleRelation = _reflection.GeneratedProtocolMessageType('RuleRelation', (_message.Message,), {
  'DESCRIPTOR' : _RULERELATION,
  '__module__' : 'th2_grpc_sim.sim_pb2'
  # @@protoc_insertion_point(class_scope:RuleRelation)
  })
_sym_db.RegisterMessage(RuleRelation)

RuleInfo = _reflection.GeneratedProtocolMessageType('RuleInfo', (_message.Message,), {
  'DESCRIPTOR' : _RULEINFO,
  '__module__' : 'th2_grpc_sim.sim_pb2'
  # @@protoc_insertion_point(class_scope:RuleInfo)
  })
_sym_db.RegisterMessage(RuleInfo)

RulesInfo = _reflection.GeneratedProtocolMessageType('RulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RULESINFO,
  '__module__' : 'th2_grpc_sim.sim_pb2'
  # @@protoc_insertion_point(class_scope:RulesInfo)
  })
_sym_db.RegisterMessage(RulesInfo)

TouchRequest = _reflection.GeneratedProtocolMessageType('TouchRequest', (_message.Message,), {

  'ArgsEntry' : _reflection.GeneratedProtocolMessageType('ArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TOUCHREQUEST_ARGSENTRY,
    '__module__' : 'th2_grpc_sim.sim_pb2'
    # @@protoc_insertion_point(class_scope:TouchRequest.ArgsEntry)
    })
  ,
  'DESCRIPTOR' : _TOUCHREQUEST,
  '__module__' : 'th2_grpc_sim.sim_pb2'
  # @@protoc_insertion_point(class_scope:TouchRequest)
  })
_sym_db.RegisterMessage(TouchRequest)
_sym_db.RegisterMessage(TouchRequest.ArgsEntry)


DESCRIPTOR._options = None
_TOUCHREQUEST_ARGSENTRY._options = None

_SIM = _descriptor.ServiceDescriptor(
  name='Sim',
  full_name='Sim',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=402,
  serialized_end=612,
  methods=[
  _descriptor.MethodDescriptor(
    name='removeRule',
    full_name='Sim.removeRule',
    index=0,
    containing_service=None,
    input_type=_RULEID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getRulesInfo',
    full_name='Sim.getRulesInfo',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_RULESINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getRelatedRules',
    full_name='Sim.getRelatedRules',
    index=2,
    containing_service=None,
    input_type=_RULERELATION,
    output_type=_RULESINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='touchRule',
    full_name='Sim.touchRule',
    index=3,
    containing_service=None,
    input_type=_TOUCHREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIM)

DESCRIPTOR.services_by_name['Sim'] = _SIM

# @@protoc_insertion_point(module_scope)
